@@ -44,8 +44,9 @@ enum service {
     SERVICES_COCKPIT        = 340,  //< cockpit management dashboard
     SERVICES_CLF_UNAUTH     = 350,  //< HTTP 401 in common log format
     SERVICES_CLF_PROBES     = 360,  //< probes for common web services
-    SERVICES_CLF_WORDPRESS  = 370,  //< WordPress logins in common log format
+    SERVICES_CLF_LOGIN_URL  = 370,  //< CMS framework logins in common log format
     SERVICES_OPENVPN        = 400,  //< OpenVPN
+    SERVICES_GITEA          = 500,  //< Gitea
 };
 
 /* an attack (source address & target service info) */
@@ -69,3 +70,5 @@ int attack_addr_seeker(const void *el, const void *key);
 int attack_from_hostname(attack_t *attack, const char *name);
 void attackerinit(attacker_t *restrict ipe, const attack_t *restrict attack);
 int attackt_whenlast_comparator(const void *a, const void *b);
+
+const char *service_to_name(enum service code);
