@@ -18,8 +18,7 @@
  * SSHGuard. See http://www.sshguard.net
  */
 
-#ifndef PARSER_H
-#define PARSER_H
+#pragma once
 
 /* also define global var yydebug = 1 for enabling debugging at runtime */
 #define YYDEBUG 1
@@ -28,12 +27,10 @@ extern int yydebug;
 extern int yy_flex_debug;
 #endif
 
-#include "parser/attack.h"
+#include "attack.h"
 
 /**
  * Parse a single line of a log for an attack. If an attack is found, return
  * zero and store the attack in the given pointer.
  */
-int parse_line(int source_id, char *str, attack_t *attack);
-
-#endif
+int parse_line(char *str, attack_t *attack);
